@@ -20,20 +20,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef SCREENLOCKER_WAYLANDSERVER_H
 #define SCREENLOCKER_WAYLANDSERVER_H
 
-#include <QObject>
+#include <QSocketNotifier>
 
-struct wl_client;
-struct wl_global;
-struct wl_resource;
-
-namespace KWayland
-{
-namespace Server
-{
-class ClientConnection;
-class Display;
-}
-}
+#include <wayland-server.h>
 
 namespace ScreenLocker
 {
@@ -50,19 +39,20 @@ Q_SIGNALS:
     void x11WindowAdded(quint32 window);
 
 private:
+    void flush();
+    void dispatchEvents();
+
     static void bind(wl_client *client, void *data, uint32_t version, uint32_t id);
-    static void unbind(wl_resource *resource);
-    static void x11WindowCallback(wl_client *client, wl_resource *resource, uint32_t id);
-    static void suspendSystemCallback(wl_client *client, wl_resource *resource);
-    static void hibernateSystemCallback(wl_client *client, wl_resource *resource);
-    void addResource(wl_resource *r);
-    void removeResource(wl_resource *r);
-    void sendCanSuspend();
-    void sendCanHibernate();
-    QScopedPointer<KWayland::Server::Display> m_display;
-    KWayland::Server::ClientConnection *m_allowedClient = nullptr;
-    wl_global *m_interface = nullptr;
-    QList<wl_resource *> m_resources;
+
+    QSocketNotifier *m_notifier = nullptr;
+    ::wl_display *m_display = nullptr;
+    ::wl_client *m_greeter = nullptr;
+    ::wl_global *m_interface = nullptr;
+
+    struct Listener {
+        ::wl_listener listener;
+        WaylandServer *server;
+    } m_listener;
 };
 
 }
